==> interzone-1.0.7.tar.gz: lib/moderator/OutgoingMessageCache.dart <==
import 'dart:typed_data';

import 'OutgoingMessage.dart';

class OutgoingMessageCache {
  Map<int, OutgoingMessage> _data = {};
  Set<int> _sent = {};
  Set<int> _pending = {};

  OutgoingMessage? get pendingItem {
    if (_data.isEmpty) return null;
    final p = _data.keys
        .where((element) =>
            !_sent.contains(element) && !_pending.contains(element))
        .toList();
    if (p.isEmpty) return null;
    return _data[p.first];
  }

  void holdPendingItem(int i) {
    _pending.add(i);
  }

  void releasePendingItem(int i) {
    _pending.remove(i);
  }

  bool addPost(nick, text, rootKey, ppKey, timestamp, attachement, cid) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] = OutgoingMessage(
        0, nick, text, rootKey, ppKey, timestamp, attachement, cid);
    return true;
  }

  bool addReply(nick, text, rootKey, ppKey, timestamp, attachement, cid) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] = OutgoingMessage(
        1, nick, text, rootKey, ppKey, timestamp, attachement, cid);
    return true;
  }

  bool addDrop(String rootKey, int timestamp) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] =
        OutgoingMessage(2, '', '', rootKey, '', timestamp, Uint8List(0), 'cid');
    return true;
  }

  bool addMute(String rootKey, int timestamp) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] =
        OutgoingMessage(3, '', '', rootKey, '', timestamp, Uint8List(0), 'cid');
    return true;
  }

  bool addShare(String rootKey, int timestamp) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] =
        OutgoingMessage(5, '', '', rootKey, '', timestamp, Uint8List(0), 'cid');
    return true;
  }

  bool commitSent(timestamp) {
    _sent.add(timestamp);
    releasePendingItem(timestamp);
    _data.remove(timestamp);
    return true;
  }

  bool setCID(timestamp, cid) {
    if (_data[timestamp] == null) return false;
    _data[timestamp]!.cid = cid;
    return true;
  }
}

==> interzone-1.0.11.tar.gz: lib/moderator/OutgoingMessageCache.dart <==
import 'dart:typed_data';

import 'OutgoingMessage.dart';

class OutgoingMessageCache {
  Map<int, OutgoingMessage> _data = {};
  Set<int> _sent = {};
  Set<int> _pending = {};

  OutgoingMessage? get pendingItem {
    if (_data.isEmpty) return null;
    final p = _data.keys
        .where((element) =>
            !_sent.contains(element) && !_pending.contains(element))
        .toList();
    if (p.isEmpty) return null;
    return _data[p.first];
  }

  void holdPendingItem(int i) {
    _pending.add(i);
  }

  void releasePendingItem(int i) {
    _pending.remove(i);
  }

  bool addPost(
      nick, avatar, text, rootKey, ppKey, timestamp, attachement, cid) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] = OutgoingMessage(
        0, nick, text, rootKey, ppKey, timestamp, attachement, cid);
    return true;
  }

  bool addReply(
      nick, avatar, text, rootKey, ppKey, timestamp, attachement, cid) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] = OutgoingMessage(
        1, nick, text, rootKey, ppKey, timestamp, attachement, cid);
    return true;
  }

  bool addDrop(String rootKey, int timestamp) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] =
        OutgoingMessage(3, '', '', rootKey, '', timestamp, Uint8List(0), 'cid');
    return true;
  }

  bool addMute(String rootKey, int timestamp) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] =
        OutgoingMessage(4, '', '', rootKey, '', timestamp, Uint8List(0), 'cid');
    return true;
  }

  bool addShare(String rootKey, int timestamp) {
    if (_data[timestamp] != null) return false;
    if (_sent.contains(timestamp)) return false;

    _data[timestamp] =
        OutgoingMessage(5, '', '', rootKey, '', timestamp, Uint8List(0), 'cid');
    return true;
  }

  bool commitSent(timestamp) {
    _sent.add(timestamp);
    releasePendingItem(timestamp);
    _data.remove(timestamp);
    return true;
  }

  bool setCID(timestamp, cid) {
    if (_data[timestamp] == null) return false;
    _data[timestamp]!.cid = cid;
    return true;
  }
}
